@@ -1,12 +1,12 @@
 from dataclasses import dataclass
-from typing import List, Text, Type
+from typing import Type
 
-from . import Entity
 from ..serializers import Serializer
+from . import Entity
 
 
 @dataclass
 class EntityRegistry:
+    # TODO: currently Entity.Meta.keys can be edited after initialization, it should be handled somehow.
     entity_type: Type[Entity]
     serializer: Serializer
-    key_fields: List[Text]
