@@ -1,5 +1,5 @@
 from abc import ABC
-from typing import Text, List, Optional, Any
+from typing import Any, List, Optional, Text
 
 from data_snack.entities import Entity
 
@@ -12,16 +12,7 @@ class Wrap(ABC):
     def __init__(self, *args: Any, **kwargs: Any):
         ...
 
-    def set(self, entity: Entity) -> Optional[Text]:
-        """
-        Saves given entity in db.
-
-        :param entity: an entity
-        :return: a key to saved entity
-        """
-        ...
-
-    def get(self, key_values: List[Text]) -> Entity:
+    def get(self, key_values: List[Any]) -> Entity:
         """
         Reads entities from db based on provided key values.
 
@@ -30,7 +21,26 @@ class Wrap(ABC):
         """
         ...
 
-    def get_many(self, keys_values: List[List[Text]]) -> List[Entity]:
+    def set(self, entity: Entity, expire: int = 0) -> Optional[Text]:
+        """
+        Saves given entity in db.
+
+        :param entity: an entity
+        :param expire: number of seconds until the item is expired, or zero for no expiry
+        :return: a key to saved entity
+        """
+        ...
+
+    def delete(self, key_values: List[Any]) -> Entity:
+        """
+        Reads entities from db based on provided key values.
+
+        :param key_values: a list of values from key fields
+        :return: an entity retrieved from db
+        """
+        ...
+
+    def get_many(self, keys_values: List[List[Any]]) -> List[Entity]:
         """
         Gets list of `Entity` objects from db based on provided list of keys.
 
@@ -48,6 +58,15 @@ class Wrap(ABC):
         """
         ...
 
+    def delete_many(self, keys_values: List[List[Any]]) -> bool:
+        """
+        Deletes list of `Entity` objects from db based on provided list of keys.
+
+        :param keys_values: a list of key values
+        :return: True if data were deleted
+        """
+        ...
+
     def keys(self) -> List[bytes]:
         """
         Reads a list of keys available in db for given `Entity` type.
